@@ -25,7 +25,7 @@ Usage::
     list_keys_paginator: ListKeysPaginator = client.get_paginator("list_keys")
     ```
 """
-from mypy_boto3_kms.client import KMSClient as Client, KMSClient
+from mypy_boto3_kms.client import KMSClient, KMSClient as Client
 from mypy_boto3_kms.paginator import (
     ListAliasesPaginator,
     ListGrantsPaginator,
