@@ -3,13 +3,15 @@ Main interface for kms service type definitions.
 
 Usage::
 
-    from mypy_boto3.kms.type_defs import CancelKeyDeletionResponseTypeDef
+    ```python
+    from mypy_boto3_kms.type_defs import AliasListEntryTypeDef
 
-    data: CancelKeyDeletionResponseTypeDef = {...}
+    data: AliasListEntryTypeDef = {...}
+    ```
 """
 from datetime import datetime
 import sys
-from typing import Dict, IO, List, Union
+from typing import Dict, List
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -22,13 +24,18 @@ else:
 
 
 __all__ = (
+    "AliasListEntryTypeDef",
+    "CustomKeyStoresListEntryTypeDef",
+    "GrantConstraintsTypeDef",
+    "GrantListEntryTypeDef",
+    "KeyListEntryTypeDef",
+    "KeyMetadataTypeDef",
+    "TagTypeDef",
     "CancelKeyDeletionResponseTypeDef",
     "CreateCustomKeyStoreResponseTypeDef",
     "CreateGrantResponseTypeDef",
-    "KeyMetadataTypeDef",
     "CreateKeyResponseTypeDef",
     "DecryptResponseTypeDef",
-    "CustomKeyStoresListEntryTypeDef",
     "DescribeCustomKeyStoresResponseTypeDef",
     "DescribeKeyResponseTypeDef",
     "EncryptResponseTypeDef",
@@ -41,15 +48,10 @@ __all__ = (
     "GetKeyRotationStatusResponseTypeDef",
     "GetParametersForImportResponseTypeDef",
     "GetPublicKeyResponseTypeDef",
-    "GrantConstraintsTypeDef",
-    "AliasListEntryTypeDef",
     "ListAliasesResponseTypeDef",
-    "GrantListEntryTypeDef",
     "ListGrantsResponseTypeDef",
     "ListKeyPoliciesResponseTypeDef",
-    "KeyListEntryTypeDef",
     "ListKeysResponseTypeDef",
-    "TagTypeDef",
     "ListResourceTagsResponseTypeDef",
     "PaginatorConfigTypeDef",
     "ReEncryptResponseTypeDef",
@@ -58,18 +60,77 @@ __all__ = (
     "VerifyResponseTypeDef",
 )
 
-CancelKeyDeletionResponseTypeDef = TypedDict(
-    "CancelKeyDeletionResponseTypeDef", {"KeyId": str}, total=False
+AliasListEntryTypeDef = TypedDict(
+    "AliasListEntryTypeDef", {"AliasName": str, "AliasArn": str, "TargetKeyId": str}, total=False
 )
 
-CreateCustomKeyStoreResponseTypeDef = TypedDict(
-    "CreateCustomKeyStoreResponseTypeDef", {"CustomKeyStoreId": str}, total=False
+CustomKeyStoresListEntryTypeDef = TypedDict(
+    "CustomKeyStoresListEntryTypeDef",
+    {
+        "CustomKeyStoreId": str,
+        "CustomKeyStoreName": str,
+        "CloudHsmClusterId": str,
+        "TrustAnchorCertificate": str,
+        "ConnectionState": Literal[
+            "CONNECTED", "CONNECTING", "FAILED", "DISCONNECTED", "DISCONNECTING"
+        ],
+        "ConnectionErrorCode": Literal[
+            "INVALID_CREDENTIALS",
+            "CLUSTER_NOT_FOUND",
+            "NETWORK_ERRORS",
+            "INTERNAL_ERROR",
+            "INSUFFICIENT_CLOUDHSM_HSMS",
+            "USER_LOCKED_OUT",
+            "USER_NOT_FOUND",
+            "USER_LOGGED_IN",
+            "SUBNET_NOT_FOUND",
+        ],
+        "CreationDate": datetime,
+    },
+    total=False,
 )
 
-CreateGrantResponseTypeDef = TypedDict(
-    "CreateGrantResponseTypeDef", {"GrantToken": str, "GrantId": str}, total=False
+GrantConstraintsTypeDef = TypedDict(
+    "GrantConstraintsTypeDef",
+    {"EncryptionContextSubset": Dict[str, str], "EncryptionContextEquals": Dict[str, str]},
+    total=False,
 )
 
+GrantListEntryTypeDef = TypedDict(
+    "GrantListEntryTypeDef",
+    {
+        "KeyId": str,
+        "GrantId": str,
+        "Name": str,
+        "CreationDate": datetime,
+        "GranteePrincipal": str,
+        "RetiringPrincipal": str,
+        "IssuingAccount": str,
+        "Operations": List[
+            Literal[
+                "Decrypt",
+                "Encrypt",
+                "GenerateDataKey",
+                "GenerateDataKeyWithoutPlaintext",
+                "ReEncryptFrom",
+                "ReEncryptTo",
+                "Sign",
+                "Verify",
+                "GetPublicKey",
+                "CreateGrant",
+                "RetireGrant",
+                "DescribeKey",
+                "GenerateDataKeyPair",
+                "GenerateDataKeyPairWithoutPlaintext",
+            ]
+        ],
+        "Constraints": "GrantConstraintsTypeDef",
+    },
+    total=False,
+)
+
+KeyListEntryTypeDef = TypedDict("KeyListEntryTypeDef", {"KeyId": str, "KeyArn": str}, total=False)
+
 _RequiredKeyMetadataTypeDef = TypedDict("_RequiredKeyMetadataTypeDef", {"KeyId": str})
 _OptionalKeyMetadataTypeDef = TypedDict(
     "_OptionalKeyMetadataTypeDef",
@@ -125,15 +186,29 @@ class KeyMetadataTypeDef(_RequiredKeyMetadataTypeDef, _OptionalKeyMetadataTypeDe
     pass
 
 
+TagTypeDef = TypedDict("TagTypeDef", {"TagKey": str, "TagValue": str})
+
+CancelKeyDeletionResponseTypeDef = TypedDict(
+    "CancelKeyDeletionResponseTypeDef", {"KeyId": str}, total=False
+)
+
+CreateCustomKeyStoreResponseTypeDef = TypedDict(
+    "CreateCustomKeyStoreResponseTypeDef", {"CustomKeyStoreId": str}, total=False
+)
+
+CreateGrantResponseTypeDef = TypedDict(
+    "CreateGrantResponseTypeDef", {"GrantToken": str, "GrantId": str}, total=False
+)
+
 CreateKeyResponseTypeDef = TypedDict(
-    "CreateKeyResponseTypeDef", {"KeyMetadata": KeyMetadataTypeDef}, total=False
+    "CreateKeyResponseTypeDef", {"KeyMetadata": "KeyMetadataTypeDef"}, total=False
 )
 
 DecryptResponseTypeDef = TypedDict(
     "DecryptResponseTypeDef",
     {
         "KeyId": str,
-        "Plaintext": Union[bytes, IO],
+        "Plaintext": bytes,
         "EncryptionAlgorithm": Literal[
             "SYMMETRIC_DEFAULT", "RSAES_OAEP_SHA_1", "RSAES_OAEP_SHA_256"
         ],
@@ -141,36 +216,10 @@ DecryptResponseTypeDef = TypedDict(
     total=False,
 )
 
-CustomKeyStoresListEntryTypeDef = TypedDict(
-    "CustomKeyStoresListEntryTypeDef",
-    {
-        "CustomKeyStoreId": str,
-        "CustomKeyStoreName": str,
-        "CloudHsmClusterId": str,
-        "TrustAnchorCertificate": str,
-        "ConnectionState": Literal[
-            "CONNECTED", "CONNECTING", "FAILED", "DISCONNECTED", "DISCONNECTING"
-        ],
-        "ConnectionErrorCode": Literal[
-            "INVALID_CREDENTIALS",
-            "CLUSTER_NOT_FOUND",
-            "NETWORK_ERRORS",
-            "INTERNAL_ERROR",
-            "INSUFFICIENT_CLOUDHSM_HSMS",
-            "USER_LOCKED_OUT",
-            "USER_NOT_FOUND",
-            "USER_LOGGED_IN",
-            "SUBNET_NOT_FOUND",
-        ],
-        "CreationDate": datetime,
-    },
-    total=False,
-)
-
 DescribeCustomKeyStoresResponseTypeDef = TypedDict(
     "DescribeCustomKeyStoresResponseTypeDef",
     {
-        "CustomKeyStores": List[CustomKeyStoresListEntryTypeDef],
+        "CustomKeyStores": List["CustomKeyStoresListEntryTypeDef"],
         "NextMarker": str,
         "Truncated": bool,
     },
@@ -178,13 +227,13 @@ DescribeCustomKeyStoresResponseTypeDef = TypedDict(
 )
 
 DescribeKeyResponseTypeDef = TypedDict(
-    "DescribeKeyResponseTypeDef", {"KeyMetadata": KeyMetadataTypeDef}, total=False
+    "DescribeKeyResponseTypeDef", {"KeyMetadata": "KeyMetadataTypeDef"}, total=False
 )
 
 EncryptResponseTypeDef = TypedDict(
     "EncryptResponseTypeDef",
     {
-        "CiphertextBlob": Union[bytes, IO],
+        "CiphertextBlob": bytes,
         "KeyId": str,
         "EncryptionAlgorithm": Literal[
             "SYMMETRIC_DEFAULT", "RSAES_OAEP_SHA_1", "RSAES_OAEP_SHA_256"
@@ -196,9 +245,9 @@ EncryptResponseTypeDef = TypedDict(
 GenerateDataKeyPairResponseTypeDef = TypedDict(
     "GenerateDataKeyPairResponseTypeDef",
     {
-        "PrivateKeyCiphertextBlob": Union[bytes, IO],
-        "PrivateKeyPlaintext": Union[bytes, IO],
-        "PublicKey": Union[bytes, IO],
+        "PrivateKeyCiphertextBlob": bytes,
+        "PrivateKeyPlaintext": bytes,
+        "PublicKey": bytes,
         "KeyId": str,
         "KeyPairSpec": Literal[
             "RSA_2048",
@@ -216,8 +265,8 @@ GenerateDataKeyPairResponseTypeDef = TypedDict(
 GenerateDataKeyPairWithoutPlaintextResponseTypeDef = TypedDict(
     "GenerateDataKeyPairWithoutPlaintextResponseTypeDef",
     {
-        "PrivateKeyCiphertextBlob": Union[bytes, IO],
-        "PublicKey": Union[bytes, IO],
+        "PrivateKeyCiphertextBlob": bytes,
+        "PublicKey": bytes,
         "KeyId": str,
         "KeyPairSpec": Literal[
             "RSA_2048",
@@ -234,18 +283,18 @@ GenerateDataKeyPairWithoutPlaintextResponseTypeDef = TypedDict(
 
 GenerateDataKeyResponseTypeDef = TypedDict(
     "GenerateDataKeyResponseTypeDef",
-    {"CiphertextBlob": Union[bytes, IO], "Plaintext": Union[bytes, IO], "KeyId": str},
+    {"CiphertextBlob": bytes, "Plaintext": bytes, "KeyId": str},
     total=False,
 )
 
 GenerateDataKeyWithoutPlaintextResponseTypeDef = TypedDict(
     "GenerateDataKeyWithoutPlaintextResponseTypeDef",
-    {"CiphertextBlob": Union[bytes, IO], "KeyId": str},
+    {"CiphertextBlob": bytes, "KeyId": str},
     total=False,
 )
 
 GenerateRandomResponseTypeDef = TypedDict(
-    "GenerateRandomResponseTypeDef", {"Plaintext": Union[bytes, IO]}, total=False
+    "GenerateRandomResponseTypeDef", {"Plaintext": bytes}, total=False
 )
 
 GetKeyPolicyResponseTypeDef = TypedDict("GetKeyPolicyResponseTypeDef", {"Policy": str}, total=False)
@@ -256,12 +305,7 @@ GetKeyRotationStatusResponseTypeDef = TypedDict(
 
 GetParametersForImportResponseTypeDef = TypedDict(
     "GetParametersForImportResponseTypeDef",
-    {
-        "KeyId": str,
-        "ImportToken": Union[bytes, IO],
-        "PublicKey": Union[bytes, IO],
-        "ParametersValidTo": datetime,
-    },
+    {"KeyId": str, "ImportToken": bytes, "PublicKey": bytes, "ParametersValidTo": datetime},
     total=False,
 )
 
@@ -269,7 +313,7 @@ GetPublicKeyResponseTypeDef = TypedDict(
     "GetPublicKeyResponseTypeDef",
     {
         "KeyId": str,
-        "PublicKey": Union[bytes, IO],
+        "PublicKey": bytes,
         "CustomerMasterKeySpec": Literal[
             "RSA_2048",
             "RSA_3072",
@@ -301,58 +345,15 @@ GetPublicKeyResponseTypeDef = TypedDict(
     total=False,
 )
 
-GrantConstraintsTypeDef = TypedDict(
-    "GrantConstraintsTypeDef",
-    {"EncryptionContextSubset": Dict[str, str], "EncryptionContextEquals": Dict[str, str]},
-    total=False,
-)
-
-AliasListEntryTypeDef = TypedDict(
-    "AliasListEntryTypeDef", {"AliasName": str, "AliasArn": str, "TargetKeyId": str}, total=False
-)
-
 ListAliasesResponseTypeDef = TypedDict(
     "ListAliasesResponseTypeDef",
-    {"Aliases": List[AliasListEntryTypeDef], "NextMarker": str, "Truncated": bool},
-    total=False,
-)
-
-GrantListEntryTypeDef = TypedDict(
-    "GrantListEntryTypeDef",
-    {
-        "KeyId": str,
-        "GrantId": str,
-        "Name": str,
-        "CreationDate": datetime,
-        "GranteePrincipal": str,
-        "RetiringPrincipal": str,
-        "IssuingAccount": str,
-        "Operations": List[
-            Literal[
-                "Decrypt",
-                "Encrypt",
-                "GenerateDataKey",
-                "GenerateDataKeyWithoutPlaintext",
-                "ReEncryptFrom",
-                "ReEncryptTo",
-                "Sign",
-                "Verify",
-                "GetPublicKey",
-                "CreateGrant",
-                "RetireGrant",
-                "DescribeKey",
-                "GenerateDataKeyPair",
-                "GenerateDataKeyPairWithoutPlaintext",
-            ]
-        ],
-        "Constraints": GrantConstraintsTypeDef,
-    },
+    {"Aliases": List["AliasListEntryTypeDef"], "NextMarker": str, "Truncated": bool},
     total=False,
 )
 
 ListGrantsResponseTypeDef = TypedDict(
     "ListGrantsResponseTypeDef",
-    {"Grants": List[GrantListEntryTypeDef], "NextMarker": str, "Truncated": bool},
+    {"Grants": List["GrantListEntryTypeDef"], "NextMarker": str, "Truncated": bool},
     total=False,
 )
 
@@ -362,19 +363,15 @@ ListKeyPoliciesResponseTypeDef = TypedDict(
     total=False,
 )
 
-KeyListEntryTypeDef = TypedDict("KeyListEntryTypeDef", {"KeyId": str, "KeyArn": str}, total=False)
-
 ListKeysResponseTypeDef = TypedDict(
     "ListKeysResponseTypeDef",
-    {"Keys": List[KeyListEntryTypeDef], "NextMarker": str, "Truncated": bool},
+    {"Keys": List["KeyListEntryTypeDef"], "NextMarker": str, "Truncated": bool},
     total=False,
 )
 
-TagTypeDef = TypedDict("TagTypeDef", {"TagKey": str, "TagValue": str})
-
 ListResourceTagsResponseTypeDef = TypedDict(
     "ListResourceTagsResponseTypeDef",
-    {"Tags": List[TagTypeDef], "NextMarker": str, "Truncated": bool},
+    {"Tags": List["TagTypeDef"], "NextMarker": str, "Truncated": bool},
     total=False,
 )
 
@@ -385,7 +382,7 @@ PaginatorConfigTypeDef = TypedDict(
 ReEncryptResponseTypeDef = TypedDict(
     "ReEncryptResponseTypeDef",
     {
-        "CiphertextBlob": Union[bytes, IO],
+        "CiphertextBlob": bytes,
         "SourceKeyId": str,
         "KeyId": str,
         "SourceEncryptionAlgorithm": Literal[
@@ -406,7 +403,7 @@ SignResponseTypeDef = TypedDict(
     "SignResponseTypeDef",
     {
         "KeyId": str,
-        "Signature": Union[bytes, IO],
+        "Signature": bytes,
         "SigningAlgorithm": Literal[
             "RSASSA_PSS_SHA_256",
             "RSASSA_PSS_SHA_384",
